1. Building a simple blog with CubicWeb — CubicWeb 3.13.2

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.13.2 »
- Tutorials »

# 1. Building a simple blog with CubicWeb

CubicWeb is a semantic web application framework that favors reuse and object-oriented design.

This tutorial is designed to help in your very first steps to start with CubicWeb. We will tour through basic concepts such as:

- getting an application running by using existing components
- discovering the default user interface
- basic extending and customizing the look and feel of that application

More advanced concepts are covered in Building a photo gallery with CubicWeb.

## 1.1. Some vocabulary

CubicWeb comes with a few words of vocabulary that you should know to understand what we’re talking about. To follow this tutorial, you should at least know that:

- a cube is a component that usually includes a model defining some data types and a set of views to display them. A cube can be built by assembling other cubes;
- an instance is a specific installation of one or more cubes and includes configuration files, a web server and a database.

Reading The Core Concepts of CubicWeb for more vocabulary will be required at some point.

Now, let’s start the hot stuff!

- 1.1.1. Get a blog running in five minutes!
  - 1.1.1.1. About file system permissions
  - 1.1.1.2. Instance parameters
- 1.1.2. Discovering the web interface
  - 1.1.2.1. Minimal configuration
  - 1.1.2.2. Adding entities
  - 1.1.2.3. About ui auto-adaptation
  - 1.1.2.4. Digging deeper
- 1.1.3. Customizing your application
  - 1.1.3.1. Create your own cube
  - 1.1.3.2. Cube metadata
  - 1.1.3.3. Extending the data model
  - 1.1.3.4. Defining your views
  - 1.1.3.5. Changing the layout of the application
  - 1.1.3.6. Primary view customization
  - 1.1.3.7. Write entities to add logic in your data
  - 1.1.3.8. Extending the application by using more cubes!
- 1.1.4. What’s next?

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.13.2 »
- Tutorials »